# 021

|                                                        | 021-df8ae1406f86cade   |
|:-------------------------------------------------------|:-----------------------|
| bindTime                                               | 1629724970364          |
| createTime                                             | 0                      |
| deviceFeatureCode                                      | df8ae1406f86cade       |
| deviceFeatureName                                      | HOOD                   |
| deviceId                                               | <redacted>             |
| deviceNickName                                         | ASKO hood              |
| deviceTypeCode                                         | 021                    |
| deviceTypeName                                         |                        |
| offlineState                                           | 1                      |
| puid                                                   | <redacted>             |
| role                                                   | 1                      |
| roomId                                                 | 142500                 |
| roomName                                               | AR kitchen             |
| seq                                                    | 0                      |
| statusList.Alarm_grease_filter                         | 0                      |
| statusList.Alarm_recirculation_filter1                 | 0                      |
| statusList.Clean_air_active                            | 6061                   |
| statusList.Clean_air_active_passed_hours               | 0                      |
| statusList.Clean_air_active_total_hours                | 100                    |
| statusList.Clean_air_duration_of_cycle_in_minutes      | 60                     |
| statusList.Clean_air_motor_level                       | 1                      |
| statusList.Delay_off_time                              | 0                      |
| statusList.Device_status                               | 6014                   |
| statusList.Grease_filter_cleaning_interval_in_hours    | 100                    |
| statusList.Grease_filter_set_lifetime_in_hours         | 100                    |
| statusList.Grease_filter_timer_active                  | 6247                   |
| statusList.Grease_filter_used_hours                    | 100                    |
| statusList.Hard_pairing_status                         | 9106                   |
| statusList.Light_brightness                            | 100                    |
| statusList.Light_color_temperature                     | 0                      |
| statusList.Light_status                                | 1                      |
| statusList.Maximum_motor_level                         | 5                      |
| statusList.Motor_level                                 | 5                      |
| statusList.Recirculation_filter1_set_lifetime_in_hours | 2000                   |
| statusList.Recirculation_filter1_timer_active          | 6252                   |
| statusList.Recirculation_filter1_type                  | 1                      |
| statusList.Recirculation_filter1_used_hours            | 127                    |
| statusList.Remote_control_mode                         | 1                      |
| statusList.Timer_status                                | 6201                   |
| statusList.UTC_dateTime_BDC_timer_end_time_timestamp   | 2024/03/17T20:29:56    |
| statusList.UTC_dateTime_BDC_timer_start_time_timestamp | 2024/03/17T20:19:56    |
| statusList.daily_energy_kwh                            | 0                      |
| useTime                                                | 0                      |
| wifiId                                                 | <redacted>             |

## Generated from

- [`021`](021-df8ae1406f86cade.json)
